@@ -1,19 +1,25 @@
 '''Asynchronous Redis-backed reliable queue package.'''
 
 
-import json
-import uuid
-import time
-import enum
 import asyncio
-import hashlib
-import logging
 import contextlib
+import enum
+import hashlib
+import json
+import logging
+import time
+import uuid
 
 import aredis
 
 
-__all__ = 'Torrelque', 'TorrelqueTaskStatus'
+__all__ = (
+    'Torrelque',
+    'TorrelqueTaskStatus',
+    'TorrelqueError',
+    'TorrelqueTimeoutError',
+    'TorrelqueLookupError',
+)
 
 logger = logging.getLogger(__package__)
 
@@ -42,16 +48,31 @@ class TorrelqueTaskStatus(enum.IntEnum):
         return self in (self.COMPLETED, self.REJECTED)
 
 
+class TorrelqueError(Exception):
+    '''Generic Torrelque error.'''
+
+
+class TorrelqueTimeoutError(Exception):
+    '''Torrelque timeout error.'''
+
+
+class TorrelqueLookupError(Exception):
+    '''Torrelque lookup error.'''
+
+
 class Torrelque:
     '''
     Reliable work queue.
 
-    :param redis: Redis client instance.
+    :param redis:
+        Redis client instance.
     :param queue:
         Name of the queue. Must match across producers and consumers.
     :param serialiser:
         An object with ``dumps`` and ``loads`` that (de)serialises
         task bodies.
+    :raises TorrelqueError:
+        Not a ``aredis.StrictRedis`` instance passed.
     '''
 
     task_timeout = 300
@@ -100,7 +121,7 @@ class Torrelque:
 
     def __init__(self, redis: aredis.StrictRedis, *, queue='trq', serialiser=json):
         if not isinstance(redis, aredis.StrictRedis):
-            raise ValueError('aredis.StrictRedis instance expected')
+            raise TorrelqueError('aredis.StrictRedis instance expected')
 
         self._redis = redis
         self._serialiser = serialiser
@@ -149,7 +170,8 @@ class Torrelque:
         '''
         Put a task on the queue optionally providing its timeout and delay.
 
-        :param task: Arbitrary serialisable task payload.
+        :param task:
+            Arbitrary serialisable task payload.
         :param task_timeout:
             Time since the task's processing start after which it is
             considered stale.
@@ -160,7 +182,8 @@ class Torrelque:
             the delay only has effect after the sweep execution.
         :param pipeline:
             External Redis pipline that allows for bulk enqueue.
-        :return: Task identifier.
+        :return:
+            Task identifier.
         '''
 
         if pipeline is not None:
@@ -183,7 +206,7 @@ class Torrelque:
             self.keys['pending'], self.keys['pending'], timeout=timeout or 0
         )
         if not task_id:
-            raise TimeoutError
+            raise TorrelqueTimeoutError
 
         script = r'''
             local pending, working, tasks = unpack(KEYS)
@@ -226,9 +249,10 @@ class Torrelque:
         :param timout:
             Time to wait until the task is available.
             Note that Redis only supports an integer timeout.
-        :raises TimeoutError:
+        :raises TorrelqueTimeoutError:
             If timeout was provided and there was no result within it.
-        :return: Tuple of task identifier and deserialised task payload.
+        :return:
+            Tuple of task identifier and deserialised task payload.
         '''
 
         start = time.monotonic()
@@ -241,7 +265,7 @@ class Torrelque:
             elif timeout:
                 elapsed = time.monotonic() - start
                 if elapsed > timeout:
-                    raise TimeoutError('Total dequeue attempts timed out')
+                    raise TorrelqueTimeoutError('Total dequeue attempts timed out')
                 else:
                     iter_timeout = max(1, round(timeout - elapsed))
 
@@ -249,7 +273,8 @@ class Torrelque:
         '''
         Return failed task into the queue with optional delay.
 
-        :param task_id: Task identifier.
+        :param task_id:
+            Task identifier.
         :param delay:
             Number of seconds to delay returning the task back into
             the "pending" list. Note that the sweep must be scheduled
@@ -305,7 +330,8 @@ class Torrelque:
         with ``TorrelqueTaskStatus.REJECTED`` status if producer is
         interested in the status.
 
-        :param task_id: Task identifier.
+        :param task_id:
+            Task identifier.
         :param result:
             Arbitrary serialisable task result. If ``result`` is
             ``None`` task state key is removed immediately on release.
@@ -315,10 +341,12 @@ class Torrelque:
         :param status:
             Task status to set on release. It only apples when result
             is not ``None``.
+        :raises TorrelqueError:
+            If the status is not final.
         '''
 
         if status is not None and not status.isfinal():
-            raise ValueError(f'Invalid status for released task: {status}')
+            raise TorrelqueError(f'Invalid status for released task: {status}')
 
         expected = []
         async with await self._redis.pipeline(transaction=True) as pipe:
@@ -351,7 +379,7 @@ class Torrelque:
             notify_config = set(config['notify-keyspace-events'])
             # See https://redis.io/topics/notifications#configuration
             if {'K', 'A'} - notify_config and {'K', 'g', 'h'} - notify_config:
-                raise RuntimeError('Redis notify-keyspace-events must include KA or Kgh')
+                raise TorrelqueError('Redis notify-keyspace-events must include KA or Kgh')
             self._keyspace_notification_enabled = True
 
     async def _get_keyspace_notification_message(self, pubsub, timeout):
@@ -366,7 +394,7 @@ class Torrelque:
             # pubsub.handle_message cannot hanle.
             with contextlib.suppress(TypeError):
                 await listen_task
-            raise TimeoutError from ex
+            raise TorrelqueTimeoutError from ex
         else:
             return message
 
@@ -381,13 +409,16 @@ class Torrelque:
            commands enabled. That is, the configuration must include
            either ``KA`` or ``Kgh``.
 
-        :param task_id: Task identifier.
-        :param timeout: Timeout for watching.
-        :raises RuntimeError:
+        :param task_id:
+            Task identifier.
+        :param timeout:
+            Timeout for watching.
+        :raises TorrelqueError:
             If ``notify-keyspace-events`` is not configured properly.
-        :raises TimeoutError:
+        :raises TorrelqueTimeoutError:
             If ``watch`` has taken longer than ``timeout``.
-        :raises LookupError: If the task state key is not found.
+        :raises TorrelqueLookupError:
+            If the task state key is not found.
         :return:
             Asynchronous generator that yields task state dictionaries
             as returned by :py:meth:`.get_task_state`. Generator stops
@@ -418,7 +449,7 @@ class Torrelque:
                 elif message['data'] == b'hset':
                     try:
                         task_state = await self.get_task_state(task_id)
-                    except LookupError:
+                    except TorrelqueLookupError:
                         return  # Race condition with release
 
                     if task_state['status'] != status:
@@ -437,7 +468,8 @@ class Torrelque:
         Return stale tasks from "working" set into "pending" list.
         Move due delayed tasks from "delayed" set into "pending" list.
 
-        :return: Number of tasks requeued.
+        :return:
+            Number of tasks requeued.
         '''
 
         script = '''
@@ -495,7 +527,8 @@ class Torrelque:
         '''
         Schedule the sweep in a background coroutine.
 
-        :param interval: Override of default sweep interval.
+        :param interval:
+            Override of default sweep interval.
         '''
 
         if interval:
@@ -514,7 +547,8 @@ class Torrelque:
         '''
         Get queue counters.
 
-        :return: Dictionary containing queue counters.
+        :return:
+            Dictionary containing queue counters.
 
         ::
 
@@ -540,9 +574,12 @@ class Torrelque:
         '''
         Get task state.
 
-        :param task_id: Task identifier.
-        :raises LookupError: If the task state key is not found.
-        :return: Dictionary containing task counters and timestamps.
+        :param task_id:
+            Task identifier.
+        :raises TorrelqueLookupError:
+            If the task state key is not found.
+        :return:
+            Dictionary containing task counters and timestamps.
 
         ::
 
@@ -558,12 +595,13 @@ class Torrelque:
                 'release_time'       : 4294967295.0,
             }
 
-        :raises LookupError: If no task state key found.
+        :raises TorrelqueLookupError:
+            If no task state key found.
         '''
 
         result = await self._redis.hgetall(self._get_state_key(task_id))
         if not result:
-            raise LookupError
+            raise TorrelqueLookupError
 
         return {
             'status'             : TorrelqueTaskStatus(int(result[b'status'])),
