@@ -1,12 +1,19 @@
-import time
-import pickle
 import asyncio
+import os
+import pickle
+import time
 from unittest import mock
 
 import aredis
 import asynctest
 
-from . import Torrelque, TorrelqueTaskStatus
+from . import (
+    Torrelque,
+    TorrelqueError,
+    TorrelqueLookupError,
+    TorrelqueTaskStatus,
+    TorrelqueTimeoutError,
+)
 
 
 class TestTorrelque(asynctest.TestCase):
@@ -16,7 +23,8 @@ class TestTorrelque(asynctest.TestCase):
     serialiser = None
 
     async def setUp(self):
-        self.redis = aredis.StrictRedis(db=1)
+        dsn = os.getenv('TEST_REDIS_DSN', 'redis://localhost/1')
+        self.redis = aredis.StrictRedis.from_url(dsn)
         self.testee = Torrelque(self.redis)
 
         await self.redis.flushdb()
@@ -26,7 +34,7 @@ class TestTorrelque(asynctest.TestCase):
         self.redis.connection_pool.disconnect()
 
     def test_instantiation_error(self):
-        with self.assertRaises(ValueError) as ctx:
+        with self.assertRaises(TorrelqueError) as ctx:
             Torrelque(object())
         self.assertEqual('aredis.StrictRedis instance expected', str(ctx.exception))
 
@@ -208,7 +216,7 @@ class TestTorrelque(asynctest.TestCase):
         }, tasks)
 
 
-        with self.assertRaises(TimeoutError):
+        with self.assertRaises(TorrelqueTimeoutError):
             task_id, task_data = await self.testee.dequeue(timeout=1)
 
     async def test_dequeue_concurrent(self):
@@ -237,7 +245,7 @@ class TestTorrelque(asynctest.TestCase):
         consumer_task.cancel()
 
     async def test_dequeue_timeout_redis(self):
-        with self.assertRaises(TimeoutError):
+        with self.assertRaises(TorrelqueTimeoutError):
             await self.testee.dequeue(timeout=1)
 
     async def test_dequeue_timeout_total(self):
@@ -254,7 +262,7 @@ class TestTorrelque(asynctest.TestCase):
             return await asyncio.sleep(delays.pop(), result=(None, None))
 
         with mock.patch.object(self.testee, '_dequeue', mock_dequeue):
-            with self.assertRaises(TimeoutError) as ctx:
+            with self.assertRaises(TorrelqueTimeoutError) as ctx:
                 await self.testee.dequeue(timeout=1)
             self.assertEqual('Total dequeue attempts timed out', str(ctx.exception))
 
@@ -407,7 +415,7 @@ class TestTorrelque(asynctest.TestCase):
         actual = await self.testee.get_queue_stats()
         self.assertEqual({'working': 0, 'pending': 1, 'delayed': 0, 'tasks': 1}, actual)
 
-        with self.assertRaises(LookupError):
+        with self.assertRaises(TorrelqueLookupError):
             await self.testee.get_task_state(task_id)
 
         pending, working, delayed, tasks = await self._get_queue_state()
@@ -476,7 +484,7 @@ class TestTorrelque(asynctest.TestCase):
         self.assertEqual(10, await self.redis.ttl(self.testee._get_state_key(task_id)))
 
     async def test_release_result_invalid_status(self):
-        with self.assertRaises(ValueError) as ctx:
+        with self.assertRaises(TorrelqueError) as ctx:
             await self.testee.release('aabbccdd', result=26, status=TorrelqueTaskStatus.DELAYED)
         self.assertEqual('Invalid status for released task: 2', str(ctx.exception))
 
@@ -658,7 +666,7 @@ class TestTorrelque(asynctest.TestCase):
         await self.testee.dequeue()
         await asyncio.sleep(0.05)
 
-        with self.assertRaises(TimeoutError):
+        with self.assertRaises(TorrelqueTimeoutError):
             await watch_task
 
         for state in states:
@@ -696,7 +704,7 @@ class TestTorrelque(asynctest.TestCase):
         self.assertEqual(states, expected)
 
     async def test_watch_nonexistent(self):
-        with self.assertRaises(LookupError):
+        with self.assertRaises(TorrelqueLookupError):
             async for _ in self.testee.watch('the road'):
                 pass
 
@@ -727,14 +735,14 @@ class TestTorrelque(asynctest.TestCase):
 
     async def test_watch_invalid_keyspace_notification_config(self):
         await self.redis.config_set('notify-keyspace-events', 'Ez')
-        with self.assertRaises(RuntimeError) as ctx:
+        with self.assertRaises(TorrelqueError) as ctx:
             async for _ in self.testee.watch('someid'):
                 pass
         message = 'Redis notify-keyspace-events must include KA or Kgh'
         self.assertEqual(message, str(ctx.exception))
 
         await self.redis.config_set('notify-keyspace-events', '')
-        with self.assertRaises(RuntimeError) as ctx:
+        with self.assertRaises(TorrelqueError) as ctx:
             async for _ in self.testee.watch('someid'):
                 pass
         self.assertEqual(message, str(ctx.exception))
